//  Giuseppe Vacanti (cosine science & computing bv)
//  December  3, 2002
// 
//   $Id: saserrstr.cc,v 1.2 2003/02/11 10:19:34 gvacanti Exp $
//
// Command line interface to the error library. It is meant to be used
// by scripts so that when they are run from the GUI they generate
// compliant messages that can be parsed.
//

#include <errstr.h>

#include <boost/lexical_cast.hpp>

#include <string>

// saserrstr -m client level verbosity text
// saserrstr -[w|e|f] client label text 

namespace {
    void internalError(const std::string & s){
	errHandler.name("saserrstr");
	Sas::error("InternalError", s + std::string(" Report this."));
    }


    void do_message(const std::string & client, Msg::Layer layer,
		    Msg::Verbosity verbosity, const std::string & text) {
	errHandler.name(client);
	Sas::message(layer, verbosity, text);
    }

    enum { warning, error, fatal };

    template<int v> void do_any(const std::string & client,
				const std::string & label,
				const std::string & text) {
	errHandler.name(client);
	switch(v){
	    case warning:
		Sas::warning(label, text);
		break;
	    case error:
		Sas::error(label, text);
		break;
	    case fatal:
		Sas::fatal(label, text);
		break;
	    default:
		internalError("Cannot handle message type.");
	}
    }
	
}
int main(int argc, char * argv[]) {

    if(argc != 5 && argc != 6)
	internalError("Wrong calling sequence.");

    Msg::Layer layer;
    Msg::Verbosity verbosity;
    if(argc == 6){
	using boost::lexical_cast;
	try {
	    std::string s3(argv[3]);
	    layer = lexical_cast<Msg::Layer>(s3);
	    std::string s4(argv[4]);
	    verbosity = lexical_cast<Msg::Verbosity>(s4);
	}
	catch(boost::bad_lexical_cast & e){
	    internalError(e.what());
	}
    }
	    
    std::string what(argv[1]);
    std::string client(argv[2]);    
    if(what == "-m"){
	std::string text(argv[5]);
	do_message(client, layer, verbosity, text);
    }
    else {
	std::string label(argv[3]);
	std::string text(argv[4]);
	if(what == "-w")
	    do_any<warning>(client, label, text);
	else if(what == "-e")
	    do_any<error>(client, argv[3], argv[4]);
	else if(what == "-f")
	    do_any<fatal>(client, argv[3], argv[4]);
	else
	    internalError("Must give one of -m -w -e -f.");
    }
}
